#[non_exhaustive]pub enum AddressError {
BadPrefix(u8),
BadLength {
expected: usize,
got: usize,
},
Base58(Error),
Hex(FromHexError),
}Expand description
Errors produced when parsing or validating a TRON Address.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadPrefix(u8)
The raw address did not start with the mainnet prefix byte 0x41.
BadLength
The decoded byte slice was not the expected length.
Fields
Base58(Error)
base58check decoding failed (bad checksum or invalid characters).
Hex(FromHexError)
hex decoding failed.