pub struct UnknownResourceCode(pub i32);Expand description
Error produced when a protobuf discriminant does not name a known
ResourceCode.
Tuple Fields
0: i32The discriminant that did not match a known resource.