TxId

Type Alias TxId 

pub type TxId = B256;
A transaction id: sha256 of the protobuf-encoded raw transaction.

Defined here so it can appear in both signer and provider signatures without a dependency cycle.

Aliased Type

#[repr(transparent)]
pub struct TxId(pub [u8; 32]);

Tuple Fields

0: [u8; 32]

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes